# firefly-uas
Firefly-UAS is a Mixed-Integer Linear Programming (MILP) optimization framework developed for the location-allocation of  an Unmanned Aircraft System (UAS) consisting of drones and drone hangars to act as first responder after a reported wildfire providing real-time video streams that offer important initial insights for the control center.

## Usage

The usage of the packages is described in detail in the Jupyter Notebook `notebooks/Wildfire_UAS_Location_Optimization.ipynb`.

## Install it from PyPI

```bash
pip install firefly_uas
```

## Further information

This package was created while working on a paper named “Optimizing Autonomous Unmanned Aerial System Deployment Locations for Enhanced Wildfire Detection and Monitoring”.
